<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=ay
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Plugin uk naktayaña
',
	'aide_non_disponible' => 'Aka yanapa naktatxa janiw aka arunx wakitakiti.',
	'auteur' => 'Qillqiri:',
	'avis_acces_interdit' => 'Mantawx jark’ata.',
	'avis_article_modifie' => 'Amuyam @nom_auteur_modif@ aka qillqatax irnaqataw @date_diff@ ninkharata.',
	'avis_aucun_resultat' => 'Janiw askichat utjkiti.
',
	'avis_chemin_invalide_1' => 'Thakhix ajllita',
	'avis_chemin_invalide_2' => 'Jan jamakiw iyaw satakiti. Nayrt’ir laphi uñnaqar kutt’am ukatsti jikit yatiyawinak qhanstayam.',
	'avis_connexion_echec_1' => 'Chinuwix jalanuqirirux janiw walt’kiti MySQL.',
	'avis_connexion_echec_2' => 'Arkir laphi uñnaqar kutt’am ukatsti jikit yatiyawinaka mayamp uñjam.',
	'avis_connexion_echec_3' => '&lt;b&gt;Amuyam:&lt;/b&gt; Walja jalanuqirinakana, munasiwa &lt;b&gt;mayiña&lt;/b&gt; mantawitx naktata yatqalltawiru MySQL janir apnaqasa. Janitix chinusiñ puyrktaxa mayampi uñjam lartax ukja.',
	'avis_connexion_ldap_echec_1' => 'Jalanuqirirux chinuwi ukaxa LDAP janiw walt’kiti.',
	'avis_connexion_ldap_echec_2' => 'Nayrir laphi uñnaqar kutt’am ukatsti jikit yatiyawinak qhanstayam.',
	'avis_connexion_ldap_echec_3' => 'Mayakipawjam, askichir ukax jan apnaqamti LDAP apnaqirinak apayaniñataki.', # MODIF
	'avis_deplacement_rubrique' => '¡AMUYAM! Aka t’aqan utjiwa @contient_breves@ breve@scb@. Janitix yäqtaxa,  iyaw sat casilla uk naktayam.',
	'avis_erreur_connexion_mysql' => 'Chinuw pantjata MySQL',
	'avis_espace_interdit' => '<b>Ch’usawx jark’ata</b> <div>SPIP ukax uchantataxiwa</div>',
	'avis_lecture_noms_bases_1' => 'Uchantat pirwa yatiyawinakatxa uchantir prugramaxa janiw liykiti.',
	'avis_lecture_noms_bases_3' => 'Payir lurawinxa, inas mä pirwa apnaqiri sutimampi apnaqasispa:',
	'avis_non_acces_page' => 'Aka laphi uñnaqarux janiw mantañaniktati.',
	'avis_operation_echec' => 'Lurawix janiw walt’kiti.',
	'avis_operation_impossible' => 'Lurawix janipuni',
	'avis_suppression_base' => '¡AMUYAM, apaqat yatiyawinakax janiw askichaskaspati!',

	// B
	'bouton_acces_ldap' => 'Mä mantaw yapaña LDAP',
	'bouton_ajouter' => 'Yapaña',
	'bouton_annuler' => 'Jiwt’ayaña',
	'bouton_demande_publication' => 'Aka qillqat yatiyañ mayiña',
	'bouton_desactive_tout' => 'Taqpach jiwt’ayaña',
	'bouton_effacer_tout' => '¡Taqpach chhaqhayaña!',
	'bouton_envoyer_message' => 'Qhananchat yatiyaw: apayaña',
	'bouton_modifier' => 'Mayjachaña',
	'bouton_radio_afficher' => 'Uñachayaña',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Chint’at tanta qillqirinakan uñstaña', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Yatiyawinak utjawir apayaña:',
	'bouton_radio_envoi_liste_nouveautes' => 'Machaq tanta yatiyawinak apayaña',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Tanta qillqirinakan jan uñstaña', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Yatiyawinak qhanstat jan apayaña',
	'bouton_redirection' => 'Irpxatawi',
	'bouton_relancer_installation' => 'Mayamp uchantaw yatiyaña',
	'bouton_suivant' => 'Jutiri',
	'bouton_tenter_recuperation' => 'Askichañ yant’aña',
	'bouton_test_proxy' => 'proxy uk yant’aña',
	'bouton_vider_cache' => 'caché uk ch’usachaña',

	// C
	'cache_modifiable_webmestre' => 'Aka amuykipawix mayxt’ataspaw webmistress qamawit ukata.', # MODIF

	// D
	'date_mot_heures' => 'urasa
',

	// E
	'email' => 'aruskipayiri',
	'email_2' => 'aruskipayiri:
',
	'entree_adresse_annuaire' => 'Marpachat utjawi',
	'entree_adresse_email' => 'Aruskipayirima',
	'entree_base_donnee_1' => 'Pirwat yatiyawinakaxa utjawi',
	'entree_biographie' => 'Mä juk’a jakawipat qillqa, juk’a arunakampi...',
	'entree_chemin_acces' => '<b>Mantaña</b> mantañ thakhixa:',
	'entree_cle_pgp' => 'Impt’atama PGP',
	'entree_contenu_rubrique' => '(T’aqan utjawipa, qawqha arunakampi)',
	'entree_identifiants_connexion' => 'Chinuw uñacht’ayirinakama...',
	'entree_informations_connexion_ldap' => 'Aka phuqañ laphina yatiyawinak conexión ukata jach’a q’ipimaru LDAP. Uka yatiyawinakxa yatiyanitamwa apnaqir apnaqawita jan ukjax red ukata', # MODIF
	'entree_infos_perso' => '¿Khititasa?',
	'entree_interieur_rubrique' => 'T’aqata maqhana...',
	'entree_liens_sites' => '<b>Chinu jach’a sawu </b>(aytata, qamaw tumpañataki, ...)',
	'entree_login' => 'Sutichatama',
	'entree_login_connexion_1' => 'Chinu uñacht’ayirima',
	'entree_mot_passe' => 'Imt’awima',
	'entree_mot_passe_1' => 'Chinu imt’awima',
	'entree_mot_passe_2' => '(Awisax FTP imt’atamar ukankiwa ukatsti awisax ch’usak jayti)',
	'entree_nom_fichier' => 'K’ipit sutipa uk uchantaña @texte_compresse@:',
	'entree_nom_pseudo' => 'Sutima jan ukax sutinchama',
	'entree_nom_pseudo_1' => 'Sutima jan ukax sutinchama',
	'entree_nom_site' => 'Qamawiman sutipa',
	'entree_nouveau_passe' => 'Machaq imt’awima',
	'entree_passe_ldap' => 'Imt’awima',
	'entree_port_annuaire' => 'Marpachat thakhin jakhu',
	'entree_signature' => 'Iyawsa',
	'entree_titre_obligatoire' => '<b>Sutinchata</b> [Obligatorio]<br />',
	'entree_url' => 'Utjawi(URL) qamawimata',
	'erreur_plugin_fichier_absent' => 'Jan utjaw q’ipi
',
	'erreur_plugin_fichier_def_absent' => 'Qhanstayat q’ipix janiw utjkiti',
	'erreur_plugin_nom_fonction_interdit' => 'Lurt’awit sutix jark’ata',
	'erreur_plugin_nom_manquant' => 'Jan utjawi plugin ukan sutipa',
	'erreur_plugin_prefix_manquant' => 'Sutinakat ch’usawj pluguin ukat jan qhanstata',
	'erreur_plugin_tag_plugin_absent' => 'Janiw utjkiti &lt;plugin&gt; qhanstayawin q’ipita',
	'erreur_plugin_version_manquant' => 'Pluguin ukat uñjata jan utjkiti',

	// I
	'ical_info1' => 'Aka qamawinxa kunayman lurawinak chinusiñataki utji qamaw utjawipampi',
	'ical_info2' => 'Aka taqpach lurawinakxat juk’amp yatxatañatakix, yatxatañatakix jan pächasimti <a href="@spipnet@">illqanakawi</a>.', # MODIF
	'ical_info_calendrier' => 'Pä pachachimpuw utjtam. Mayirix qamawit mä laphi uñnaqawa kunanti taqpach yatiyat qillqatank yatiyi: jumakiw uñjtax uka mä suti imt’awi ukata, ukatxa mayjt’ayasmaw kuna pachtix munktax ukja imt’awim mayjt’ayasa.',
	'ical_methode_http' => 'Apaqaña',
	'ical_methode_webcal' => 'Kikipawi (webcal://)', # MODIF
	'ical_texte_prive' => 'Aka sapa maynit pacha chimpuxa, aka qamawit jark’ata lurawinak yatiytam (lurawinaka ukatsti sapa maynit aytatanaka, qillqatanaka ukatsti jisk’aptat amtanaka...)',
	'ical_texte_public' => 'Aka pacha chimpux uñchukiytam qamawit lurawinaka (qillqatanak ukatsti jisk’aptatanak yatiyata).',
	'ical_texte_rss' => 'Machaq yatiyawinak aka qamawitxa apxasismaw kawkir q’ipinak liyt’irimpi XML/RSS (Rich Site Summary) utt’ayataru. Ukhamaraki SPIP ukax liyt’aspaw machaq yatiyat yatiyawinaka yaqha qamawinakana kawkinti turkakipaw utt’ayatampi lurapxi (apxasit qamawinaka). ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Aruskipayirit tanta',
	'ical_titre_rss' => 'Apxasit q’ipinaka',
	'icone_activer_cookie' => '“Cookie” uk naktayaña yatiyawinakata',
	'icone_admin_plugin' => 'Pluguin ukanakat apnaqawi',
	'icone_afficher_auteurs' => 'Qillqirinaka uñachayaña',
	'icone_afficher_visiteurs' => 'Tumpirinaka uñachayaña',
	'icone_arret_discussion' => 'Aka aruskipawin jan mayamp arst’añati',
	'icone_calendrier' => 'Pachachimpu',
	'icone_creer_auteur' => 'Mä machaq qillqiri uñstayaña ukatsti aka qillqatar mayacht’aña',
	'icone_creer_rubrique_2' => 'Mä machaq t’aqa uñstayaña',
	'icone_modifier_article' => 'Aka qillqata mayjt’ayaña',
	'icone_modifier_rubrique' => 'Aka t’aqa mayjt’ayaña',
	'icone_retour' => 'Kutiña',
	'icone_retour_article' => 'Qillqatar kutiña',
	'icone_supprimer_cookie' => '\\&quot;Cookie\\&quot; uk apaqaña yatiyawinakata ',
	'icone_supprimer_rubrique' => 'Aka t’aqa a paqayaña',
	'icone_supprimer_signature' => 'Aka iyawsa apaqaña',
	'icone_valider_signature' => 'Aka iyaws iyaw saña',
	'image_administrer_rubrique' => 'Aka t’aqa apnaqasmawa',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 qillqata',
	'info_administrateur' => 'Apnaqiri', # MODIF
	'info_administrateur_1' => 'Apnaqiri', # MODIF
	'info_administrateur_2' => 'Qamawita (<i>amuyump luram</i>)',
	'info_administrateur_site_02' => 'Aka chinunx limt’am',
	'info_administrateurs' => 'Apnaqirinaka', # MODIF
	'info_administrer_rubrique' => 'Aka t’aqxa apnaqasmawa',
	'info_adresse' => 'utjawiru:',
	'info_adresse_url' => 'Utjawi (URL) jach’a qamaw utata',
	'info_aide_en_ligne' => 'SPIP naktatat yanapa',
	'info_ajouter_rubrique' => 'Apnaqañatakix yaqha t’aqa yapaña',
	'info_annonce_nouveautes' => 'Machaq yatiyawinaka yatiyaña',
	'info_article' => 'qillqata
',
	'info_article_2' => 'qillqatanaka',
	'info_article_a_paraitre' => 'Qillqatanak jutir urumpi yatiyataru',
	'info_articles_02' => 'qillqatanaka',
	'info_articles_2' => 'Qillqatanaka',
	'info_articles_auteur' => 'Aka qillqirit qillqatanaka',
	'info_articles_trouves' => 'Qillqatanak jikita',
	'info_attente_validation' => 'Qillqatanakax iyaw sañataki suyaski',
	'info_aujourdhui' => 'jichhüru:',
	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>', # MODIF
	'info_auteurs' => 'Qillqirinaka',
	'info_auteurs_par_tri' => 'Qillqirinaka@partri@',
	'info_auteurs_trouves' => 'Qillqirinaka jikita',
	'info_authentification_externe' => 'Anqax chiqpach siriwi',
	'info_avertissement' => 'Amuyam',
	'info_base_installee' => 'Ch’akha ch’akha pirwa yatiyawinakamatxa uchantataxiwa',
	'info_chapeau' => 'Qalltawi',
	'info_chapeau_2' => 'Qalltawi:',
	'info_chemin_acces_1' => 'Ajlliñatakiwa:  &lt;b&gt;&lt;/b&gt;mantañ thakhita jach’a q’ipina&lt;/b&gt;',
	'info_chemin_acces_annuaire' => 'Ajllañatakiwa:  &lt;b&gt;Mantañ thakhi jach’a q’ipina&lt;/b&gt;',
	'info_choix_base' => 'Kimsir sarawi:',
	'info_classement_1' => '° ukjaru @liste@',
	'info_classement_2' => '° ukjaru @liste@ 
',
	'info_code_acces' => '¡Mantañ chimpunakam jan armasimti!',
	'info_config_suivi_explication' => 'Tanta aruskipayiriru aka qamawitxa qillqayasismaw. Aruskipayiritxa qillqatanakat yatiyawinak qatuqata ukatsti jisk’aptat amtatanak yatiyatawiru.',
	'info_confirmer_passe' => 'Machaq imt’aw iyaw saña: ',
	'info_connexion_base' => 'Payir sarawi: &lt;b&gt;chinuñ yant’awi base ukaru&lt;/b&gt;',
	'info_connexion_ldap_ok' => 'LDAP chinuwix lurt’xiwa.</b><p> jutir sarawir sarantasmawa.</p>', # MODIF
	'info_connexion_mysql' => 'Mayir sarawi: <b> MySQL chinuwima</b>',
	'info_connexion_ok' => 'Chinuwix lurt’xiwa.',
	'info_contact' => 'Jikxatata',
	'info_contenu_articles' => 'Qillqatanakat utjawi',
	'info_creation_paragraphe' => ' (Tanta amuyunak uñstayañatakix, ch’usa siqinak jaytam)', # MODIF
	'info_creation_rubrique' => 'Janir qillqatanak qillt’asinxa, &lt;br /&gt; mä t’aqa uñstayañama.&lt;br /&gt;',
	'info_creation_tables' => 'Pusir sarawi: &lt;b&gt;base ukat uyu uyunakat uñstayawi&lt;/b&gt; ',
	'info_creer_base' => '&lt;b&gt;uñstayaña&lt;/b&gt; mä machaq yatiyawinak pirwa: ',
	'info_dans_rubrique' => 'T’aqanxa...',
	'info_date_publication_anterieure' => 'Nayrt’ir uru aka qillqawita',
	'info_date_referencement' => 'APXASIW URU AKA QAMAWITA:',
	'info_derniere_etape' => 'Qhipa sarawi: ¡tukuytanwa!',
	'info_descriptif' => 'Uñt’ayawi:',
	'info_discussion_cours' => 'Amuyt’awinakax lurasiskiw',
	'info_ecrire_article' => 'Janir qillqatanak qillqasinxa, mä t’aqa uñstayañamawa.',
	'info_email_envoi' => 'Apaw aruskipayirit utjawipa (ajlliñatakiwa)',
	'info_email_webmestre' => 'Aruskipayirit utjawipa webmaster ukata (ajlliñatakiwa)', # MODIF
	'info_envoi_email_automatique' => 'Aruskipayirinakat justup apayawi',
	'info_envoyer_maintenant' => 'Jichhaki apayaña',
	'info_etape_suivante' => 'Arkir sarawir sarantaña',
	'info_etape_suivante_1' => 'Arkir sarawir sarantasmawa',
	'info_etape_suivante_2' => 'Arkir sarawir sarantasmawa',
	'info_exportation_base' => 'base ukax apsusispaw @archive@ uka tuqiru',
	'info_facilite_suivi_activite' => 'Qillqa lurawit uñch’ukiw jasachañatakix, SPIP ukax aruskipayirit apayaspa, mä tanta qillqirinakar ukhama yatiyatawinakataki yatiyawinaka ukatak mayiwinaka, ukhamarak qillqatanakat iyaw sawi.', # MODIF
	'info_fichiers_authent' => 'Chiqpach sirit q’ipinaka «.htpasswd» ',
	'info_forums_abo_invites' => 'Qamawimax aruskipañawinakaniw qullqimp qillqatanakatakikiwa; Aka jach’a uta qamawinxa tumpirinakaru qillqayasiñataki jawthapiyi.', # MODIF
	'info_gauche_auteurs' => 'Akanxa taqpach qamawit qillqirinakaw uñsti. Kunjamaskis ukxa jisk’a saltan kulurapampiw   uñacht’ayi (apnaqiri = ch’uxña, qillqiri = q’illu).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Anqajankir qillqirinakax, qamawir jan mantañaniwa, mä laram jisk’a saltampiw uñacht’ayataski; mä wayaqamp chhaqayatakis.', # MODIF
	'info_gauche_messagerie' => 'Yatiyawirix yatiyasiwa, amtayirinak uñstyaña yatiyaw tantaru kuns apaniñapataki jan ukjax yatiyawinak yatiyaña ( apnaqir qutu ukar mayachatakis ukjax)
', # MODIF
	'info_gauche_statistiques_referers' => 'Aka Web qamawix tantanak uñicht’ayi &lt;i&gt;referers&lt;/i&gt;, qamawinakan chinunak utjkis ukhamarak juman qamawimar apapxi, masurutakiki ukhamarak jichhurutakiki; aka tantaxa sapa pä tunka urasanaka ch’usaru uskuña.',
	'info_gauche_visiteurs_enregistres' => 'Akanxa jach’a qamaw utan qillqatanakakiw jikxatasi (aruskipañawinak qillqayasiyampi)',
	'info_identification_publique' => 'Uñacht’ayawima...',
];
